@@ -1,6 +1,4 @@
-#include <R.h>
-#include <Rdefines.h>
-
+#include "threeDplot.h"
 
 
 
